==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/enums/ApplicationGatewayCustomErrorStatusCode.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * Status code of the application gateway custom error.
 */
public enum class ApplicationGatewayCustomErrorStatusCode(
    public val javaValue:
    com.pulumi.azurenative.network.enums.ApplicationGatewayCustomErrorStatusCode,
) : ConvertibleToJava<com.pulumi.azurenative.network.enums.ApplicationGatewayCustomErrorStatusCode> {
    HttpStatus400(com.pulumi.azurenative.network.enums.ApplicationGatewayCustomErrorStatusCode.HttpStatus400),
    HttpStatus403(com.pulumi.azurenative.network.enums.ApplicationGatewayCustomErrorStatusCode.HttpStatus403),
    HttpStatus404(com.pulumi.azurenative.network.enums.ApplicationGatewayCustomErrorStatusCode.HttpStatus404),
    HttpStatus405(com.pulumi.azurenative.network.enums.ApplicationGatewayCustomErrorStatusCode.HttpStatus405),
    HttpStatus408(com.pulumi.azurenative.network.enums.ApplicationGatewayCustomErrorStatusCode.HttpStatus408),
    HttpStatus500(com.pulumi.azurenative.network.enums.ApplicationGatewayCustomErrorStatusCode.HttpStatus500),
    HttpStatus502(com.pulumi.azurenative.network.enums.ApplicationGatewayCustomErrorStatusCode.HttpStatus502),
    HttpStatus503(com.pulumi.azurenative.network.enums.ApplicationGatewayCustomErrorStatusCode.HttpStatus503),
    HttpStatus504(com.pulumi.azurenative.network.enums.ApplicationGatewayCustomErrorStatusCode.HttpStatus504),
    ;

    override fun toJava():
        com.pulumi.azurenative.network.enums.ApplicationGatewayCustomErrorStatusCode = javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.network.enums.ApplicationGatewayCustomErrorStatusCode):
            ApplicationGatewayCustomErrorStatusCode =
            ApplicationGatewayCustomErrorStatusCode.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/network/kotlin/enums/ApplicationGatewayCustomErrorStatusCode.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * Status code of the application gateway custom error.
 */
public enum class ApplicationGatewayCustomErrorStatusCode(
    public val javaValue: com.pulumi.azurenative.network.enums.ApplicationGatewayCustomErrorStatusCode,
) : ConvertibleToJava<com.pulumi.azurenative.network.enums.ApplicationGatewayCustomErrorStatusCode> {
    HttpStatus400(com.pulumi.azurenative.network.enums.ApplicationGatewayCustomErrorStatusCode.HttpStatus400),
    HttpStatus403(com.pulumi.azurenative.network.enums.ApplicationGatewayCustomErrorStatusCode.HttpStatus403),
    HttpStatus404(com.pulumi.azurenative.network.enums.ApplicationGatewayCustomErrorStatusCode.HttpStatus404),
    HttpStatus405(com.pulumi.azurenative.network.enums.ApplicationGatewayCustomErrorStatusCode.HttpStatus405),
    HttpStatus408(com.pulumi.azurenative.network.enums.ApplicationGatewayCustomErrorStatusCode.HttpStatus408),
    HttpStatus500(com.pulumi.azurenative.network.enums.ApplicationGatewayCustomErrorStatusCode.HttpStatus500),
    HttpStatus502(com.pulumi.azurenative.network.enums.ApplicationGatewayCustomErrorStatusCode.HttpStatus502),
    HttpStatus503(com.pulumi.azurenative.network.enums.ApplicationGatewayCustomErrorStatusCode.HttpStatus503),
    HttpStatus504(com.pulumi.azurenative.network.enums.ApplicationGatewayCustomErrorStatusCode.HttpStatus504),
    ;

    override fun toJava(): com.pulumi.azurenative.network.enums.ApplicationGatewayCustomErrorStatusCode = javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.network.enums.ApplicationGatewayCustomErrorStatusCode): ApplicationGatewayCustomErrorStatusCode =
            ApplicationGatewayCustomErrorStatusCode.values().first { it.javaValue == javaType }
    }
}
